Animation class

This class can be used to add animations to PaintedWidget's instances.

Constructors

Animation({required List<Keyframe> keyframes, Duration duration = Duration.zero, Duration startDelay = Duration.zero, Duration endDelay = Duration.zero, Easing easing = Easing.linear, AnimationDirection direction = AnimationDirection.normal, AnimationFillMode fillMode = AnimationFillMode.none, double iterations = 1})
Creates a new Animation instance.
const

Properties

direction → AnimationDirection
final
duration → Duration
final
easing → Easing
final
endDelay → Duration
final
fillMode → AnimationFillMode
final
hashCode → int
The hash code for this object.
no setterinherited
iterations → double
final
keyframes → List<Keyframe>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDelay → Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runOnElement(Element element) → Animation
Runs this animation on the provided element.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited