Easing class

An implementation of the cubic-bezier curves.

Constructors

Easing(double x1, double y1, double x2, double y2)
Creates a new Easing instance.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x1 → double
final
x2 → double
final
y1 → double
final
y2 → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ease → const Easing
easeIn → const Easing
easeInOut → const Easing
easeOut → const Easing
linear → const Easing