Keyframe class

Similar to CSS and JS animations' keyframes.

Each keyframe has an offset, a style, and an easing property.

Constructors

Keyframe({required double offset, required Style style, Easing? easing})
Creates a new Keyframe instance.
const

Properties

easing → Easing?
final
hashCode → int
The hash code for this object.
no setterinherited
offset → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → Style
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, String>
Returns a Map representation of this Keyframe.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited