EventDetails<T extends Event> class

The details of the fired event.

Implementers

Constructors

EventDetails(T _event, {required Node<Widget> targetNode})
Creates a new instance of EventDetails.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetContext → BuildContext
The BuildContext of the Widget in the tree that fired this event.
no setter
targetElement → Element?
The html.Element of the Widget in the tree that fired this event.
no setter
targetState → State<StatefulWidget>?
The State of the Widget in the tree that fired this event.
no setter
targetWidget → Widget
The Widget in the tree that fired this event.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
stopImmediatePropagation() → void
stopPropagation() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited