PointerEventDetails class

The details of the fired pointer event.

Inheritance

Constructors

PointerEventDetails(PointerEvent _event, {required Node<Widget> targetNode})
Creates a new instance of PointerEventDetails.
const

Properties

altKey → bool
no setter
buttons → int
no setter
ctrlKey → bool
no setter
delta → Point<num>
no setter
globalPosition → Point<num>
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
isPrimary → bool
no setter
localPosition → Point<num>
no setter
pointerId → int
no setter
pointerType → PointerType
no setter
pressure → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetContext → BuildContext
The BuildContext of the Widget in the tree that fired this event.
no setterinherited
targetElement → Element?
The html.Element of the Widget in the tree that fired this event.
no setterinherited
targetState → State<StatefulWidget>?
The State of the Widget in the tree that fired this event.
no setterinherited
targetWidget → Widget
The Widget in the tree that fired this event.
no setterinherited
tiltX → int
no setter
tiltY → int
no setter
twist → int
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited