ConsumerWidget<T extends Store> class abstract

A base class for widgets that are rebuilt with the latest state of a Store provided by a Provider.

Inheritance
Implementers

Constructors

ConsumerWidget({String? key, Ref? ref})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String?
finalinherited
ref → Ref?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, T store) → Widget
createNode() → StatefulNode<StatefulWidget>
Returns a Node corresponding to this Widget at a particular location in the Node tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget.
override
matches(Widget otherWidget) → bool
Checks if two widgets match during a ReassemblableNode reassembly.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited