Container class

A Widget that paints an html.DivElement.

Inheritance

Properties

animation → Animation?
finalinherited
children → List<Widget>
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
finalinherited
onPointerCancel → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerDown → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerEnter → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerLeave → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerMove → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerOut → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerOver → PointerEventCallback<PointerEventDetails>?
finalinherited
onPointerUp → PointerEventCallback<PointerEventDetails>?
finalinherited
onScroll → EventCallback<EventDetails<Event>>?
final
onTap → EventCallback<EventDetails<Event>>?
finalinherited
ref → Ref?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → Style?
finalinherited

Methods

createNode() → ContainerNode
Returns a Node corresponding to this Widget at a particular location in the Node tree.
override
matches(Widget otherWidget) → bool
Checks if two widgets match during a ReassemblableNode reassembly.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited