Navigation extension
The navigation functions that are added to BuildContext.
- on
Methods
-
pop(
) → void -
Available on BuildContext, provided by the Navigation extension
Pops the latest modal. If all modals are popped, the current route is popped. -
pushModal(
{required void onPop()}) → void -
Available on BuildContext, provided by the Navigation extension
Pushes a new modal to the navigation state. -
pushRoute(
{required StatelessWidgetBuilder builder}) → void -
Available on BuildContext, provided by the Navigation extension
Pushes a new route synchronously. -
pushRouteLazily(
{required Future loader(), required StatelessWidgetBuilder builder}) → void -
Available on BuildContext, provided by the Navigation extension
Pushes a new route lazily. Navigator.loading is rendered while the route is being loaded.