Node<T extends Widget> class abstract

An instantiation of a Widget at a particular location in the Node tree.

Implementers

Constructors

Node(T _widget)

Properties

context → BuildContext
latefinal
hashCode → int
The hash code for this object.
no setterinherited
parentNode ↔ Node<Widget>?
latefinal
parentNodes → List<Node<Widget>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget ↔ T
If widget is updated while this Node is present in the Node tree, widgetWillUpdate and widgetDidUpdate are called.
getter/setter pair

Methods

dependenciesDidUpdate() → void
Called after the dependencies are updated.
dependOnInheritedWidgetOfExactType<U extends InheritedWidget>() → U
Returns the nearest parent InheritedWidget with the exact type U.
dispose() → void
Called after this Node is completely removed from the Node tree.
initialize() → void
Called after this Node is added to the Node tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
widgetDidUpdate(T oldWidget) → void
Called after the widget is updated. Use this to initialize the new widget.
widgetWillUpdate(T newWidget) → void
Called before the widget is updated. Use this to remove references to the previous widget.

Operators

operator ==(Object other) → bool
The equality operator.
inherited