PaintedWidget class abstract

The base class for widgets that paint an html.Element.

Inheritance
Implementers

Properties

animation → Animation?
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
finalinherited
onPointerCancel → PointerEventCallback<PointerEventDetails>?
final
onPointerDown → PointerEventCallback<PointerEventDetails>?
final
onPointerEnter → PointerEventCallback<PointerEventDetails>?
final
onPointerLeave → PointerEventCallback<PointerEventDetails>?
final
onPointerMove → PointerEventCallback<PointerEventDetails>?
final
onPointerOut → PointerEventCallback<PointerEventDetails>?
final
onPointerOver → PointerEventCallback<PointerEventDetails>?
final
onPointerUp → PointerEventCallback<PointerEventDetails>?
final
onTap → EventCallback<EventDetails<Event>>?
final
ref → Ref?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → Style?
final

Methods

createNode() → PaintedNode<PaintedWidget, Element>
Returns a Node corresponding to this Widget at a particular location in the Node tree.
override
matches(Widget otherWidget) → bool
Checks if two widgets match during a ReassemblableNode reassembly.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited