Ref class

Similar to ref in React and GlobalKey in Flutter.

Constructors

Ref()
Creates a new instance of Ref.

Properties

currentContext → BuildContext?
The BuildContext of the Widget in the tree that has this Ref.
no setter
currentElement → Element?
The html.Element of the Widget in the tree that has this Ref.
no setter
currentState → State<StatefulWidget>?
The State of the Widget in the tree that has this Ref.
no setter
currentWidget → Widget?
The Widget in the tree that has this Ref.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited