State<T extends StatefulWidget> class abstract

The logic and internal state for a StatefulWidget.

Inheritance
Mixed-in types

Constructors

State()

Properties

context → BuildContext
The location of this State in the Node tree.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isMounted → bool
Whether this State is currently in the Node tree.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration of this State.
no setter

Methods

build(BuildContext context) → Widget
Returns a single widget with the given context.
inherited
dependenciesDidUpdate() → void
Called after the dependencies are updated.
didMount() → void
Called after all child nodes are initialized.
dispose() → void
Disposes this Store.
inherited
initialize() → void
Initializes this Store.
inherited
listen(void onUpdate()) → StreamSubscription<void>
Listens to this Store for notifications.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(void callback()) → void
Notifies the listeners.
inherited
toString() → String
A string representation of this object.
inherited
widgetDidUpdate(T oldWidget) → void
Called after the configuration is updated.
willUnmount() → void
Called before the removal of this State from the tree.

Operators

operator ==(Object other) → bool
The equality operator.
inherited