StatefulBuilder class

A widget that has a State and calls a closure to obtain its child widget.

Inheritance

Constructors

StatefulBuilder(StatefulWidgetBuilder builder, {String? key, Ref? ref})
Creates a new instance of StatefulBuilder.
const

Properties

builder → StatefulWidgetBuilder
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
finalinherited
ref → Ref?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createNode() → StatefulNode<StatefulWidget>
Returns a Node corresponding to this Widget at a particular location in the Node tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget.
override
matches(Widget otherWidget) → bool
Checks if two widgets match during a ReassemblableNode reassembly.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited