TextNode class

A Node corresponding to Text.

Inheritance

Constructors

TextNode(Text widget)
Creates a new instance of TextNode.

Properties

context → BuildContext
latefinalinherited
element → SpanElement
The corresponding html.Element to this PaintedNode.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
parentNode ↔ Node<Widget>?
latefinalinherited
parentNodes → List<Node<Widget>>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget ↔ Text
If widget is updated while this Node is present in the Node tree, widgetWillUpdate and widgetDidUpdate are called.
getter/setter pairinherited

Methods

addEventSubscription<V extends Event, W extends EventDetails<V>>({required String type, required EventCallback<W>? callback, required W eventTransformer(V event)}) → void
inherited
dependenciesDidUpdate() → void
Called after the dependencies are updated.
inherited
dependOnInheritedWidgetOfExactType<U extends InheritedWidget>() → U
Returns the nearest parent InheritedWidget with the exact type U.
inherited
dispose() → void
Called after this Node is completely removed from the Node tree.
inherited
disposeElement() → void
Called before the widget is updated or when this Node is removed from the tree.
inherited
initialize() → void
Called after this Node is added to the Node tree.
inherited
initializeElement() → void
Called when this Node is added to the tree or after the widget is updated.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
widgetDidUpdate(Text oldWidget) → void
Called after the widget is updated. Use this to initialize the new widget.
inherited
widgetWillUpdate(Text newWidget) → void
Called before the widget is updated. Use this to remove references to the previous widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited